@@ -20,12 +20,14 @@
  *         Zeeshan Ali (Khattak) <zeeshanak@gnome.org>
  */
 
+const Clutter = imports.gi.Clutter;
 const GLib = imports.gi.GLib;
 const GObject = imports.gi.GObject;
 const Gio = imports.gi.Gio;
 const Gtk = imports.gi.Gtk;
 const GtkClutter = imports.gi.GtkClutter;
 const Lang = imports.lang;
+const WebKit2 = imports.gi.WebKit2;
 
 const CheckIn = imports.checkIn;
 const ContactPlace = imports.contactPlace;
@@ -36,6 +38,7 @@ const MainWindow = imports.mainWindow;
 const Maps = imports.gi.GnomeMaps;
 const NotificationManager = imports.notificationManager;
 const OSMEdit = imports.osmEdit;
+const OSMTypeSearchEntry = imports.osmTypeSearchEntry;
 const PlaceStore = imports.placeStore;
 const RouteService = imports.routeService;
 const Settings = imports.settings;
@@ -53,6 +56,10 @@ let networkMonitor = null;
 let checkInManager = null;
 let contactStore = null;
 let osmEdit = null;
+let normalStartup = true;
+
+const _ensuredTypes = [WebKit2.WebView,
+                       OSMTypeSearchEntry.OSMTypeSearchEntry];
 
 const Application = new Lang.Class({
     Name: 'Application',
@@ -77,6 +84,12 @@ const Application = new Lang.Class({
     _init: function() {
         /* Translators: This is the program name. */
         GLib.set_application_name(_("Maps"));
+        GLib.set_prgname('gnome-maps');
+
+        /* Needed to be able to use in UI files */
+        _ensuredTypes.forEach(function(type) {
+            GObject.type_ensure(type);
+        });
 
         this.parent({ application_id: 'org.gnome.Maps',
                       flags: Gio.ApplicationFlags.HANDLES_OPEN });
@@ -93,6 +106,7 @@ const Application = new Lang.Class({
             if (options.contains('local')) {
                 let variant = options.lookup_value('local', null);
                 this.local_tile_path = variant.deep_unpack();
+                normalStartup = false;
             }
 
             return -1;
@@ -150,7 +164,10 @@ const Application = new Lang.Class({
     },
 
     _onOsmAccountSetupActivate: function() {
-        osmEdit.showAccountDialog(this._mainWindow, false);
+        let dialog = osmEdit.createAccountDialog(this._mainWindow, false);
+
+        dialog.show();
+        dialog.connect('response', dialog.destroy.bind(dialog));
     },
 
     _addContacts: function() {
@@ -202,6 +219,7 @@ const Application = new Lang.Class({
     vfunc_startup: function() {
         this.parent();
 
+        Clutter.set_windowing_backend('x11,wayland,*');
         GtkClutter.init(null);
 
         Utils.loadStyleSheet(Gio.file_new_for_uri('resource:///org/gnome/Maps/application.css'));
@@ -247,9 +265,13 @@ const Application = new Lang.Class({
         let overlay = new Gtk.Overlay({ visible: true, can_focus: false });
         notificationManager = new NotificationManager.NotificationManager(overlay);
         this._mainWindow = new MainWindow.MainWindow({ application: this,
-                                                       overlay: overlay,
-                                                       opening: this._opening });
+                                                       overlay: overlay });
         this._mainWindow.connect('destroy', this._onWindowDestroy.bind(this));
+        if (GLib.getenv('MAPS_DEBUG') === 'focus') {
+            this._mainWindow.connect('set-focus', function(window, widget) {
+                log('* focus widget: %s'.format(widget));
+            });
+        }
     },
 
     vfunc_dbus_register: function(connection, path) {
@@ -283,7 +305,7 @@ const Application = new Lang.Class({
     },
 
     vfunc_open: function(files) {
-        this._opening = true;
+        normalStartup = false;
         this.activate();
 
         let mapView = this._mainWindow.mapView;
